@@ -31,6 +31,11 @@ class OdataNode(AbstractNode, abc.ABC):
         """
         return self._auth
 
+    @property
+    @abc.abstractmethod
+    def type_service(self):
+        raise NotImplementedError
+
     def __eq__(self, other):
         return isinstance(other, OdataNode) and \
             self._service_url == other._service_url
